==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/chest/dialogs_cs.lua <==

dialogId("tru-v-nasly", "font_big", "So we have finally found it.")
dialogStr("Tak jsme to konečně našly.")


dialogId("tru-m-co", "font_small", "What?")
dialogStr("Co?")


dialogId("tru-v-poklad", "font_big", "Captain Silver`s treasure, of course.")
dialogStr("No přeci poklady kapitána Silvera.")


dialogId("tru-v-gral", "font_big", "The Holy Grail, of course.")
dialogStr("No přeci svatý grál.")


dialogId("tru-v-vkupe", "font_big", "It`s neatly in one place: the treasure and the Grail.")
dialogStr("Tak to tu máme pěkně v kupě: poklady i Grál.")


dialogId("tru-m-zrada", "font_small", "I think it`s much too easy to be true.")
dialogStr("Jen aby v tom nebyla nějaká zrada.")


dialogId("tru-m-oznamit", "font_small", "I think that if it really was our goal, the game would let the player know.")
dialogStr("Já myslím, že kdyby to bylo skutečně ono, hra by to hráči nějak výrazně oznámila.")


dialogId("tru-v-stacit", "font_big", "But I have let them know. That could be enough.")
dialogStr("Však jsem mu to řekl. To by mu mohlo stačit.")


dialogId("tru-m-zpochybnit", "font_small", "But I have casted doubts on it. This could confuse them.")
dialogStr("Jenže já jsem to zpochybnila. To by jej mohlo zmást.")


dialogId("tru-v-nejspis", "font_big", "Well, all right. PROBABLY this is not what we are looking for.")
dialogStr("No tak dobře. Tak to NEJSPÍŠ ještě není ono.")


dialogId("tru-m-nejistota", "font_small", "That's better. There remains a bit of uncertainty.")
dialogStr("Tak je to lepší. Zůstává v tom střípek nejistoty.")


dialogId("tru-m-truhla0", "font_small", "Couldn`t we close that chest?")
dialogStr("Nemůže se ta truhla najednou zavřít?")


dialogId("tru-m-truhla1", "font_small", "What if we try to close that chest?")
dialogStr("Co kdybychom zkusili tu truhlu zavřít?")


dialogId("tru-v-truhla0", "font_big", "It would be much easier with the chest closed.")
dialogStr("Se zavřenou truhlou by bylo všechno jednodušší.")


dialogId("tru-v-truhla1", "font_big", "Try to push its lid.")
dialogStr("Zkus jí strčit do víka.")


dialogId("tru-m-vzit0", "font_small", "Won`t we take something with us?")
dialogStr("Nevezmeme si s sebou něco?")


dialogId("tru-m-vzit1", "font_small", "What about taking some treasure with us?")
dialogStr("Co si takhle vzít nějaký poklad s sebou?")


dialogId("tru-m-vzit2", "font_small", "Aren`t you sorry to leave all this treasure behind?")
dialogStr("Není ti líto, že tu necháme všechny ty poklady?")


dialogId("tru-v-vzit0", "font_big", "We will be glad if we manage to get out ourselves.")
dialogStr("Budeme rádi, když odjedem aspoň my samy.")


dialogId("tru-v-vzit1", "font_big", "Don`t forget our mission.")
dialogStr("Nezapomeň, že máme poslání.")


dialogId("tru-v-vzit2", "font_big", "The treasure would only hinder us.")
dialogStr("Poklady by nás jenom zdržovaly.")


dialogId("tru-v-zrak", "font_big", "All this glinting is a sight for the eyes.")
dialogStr("Už mě z toho lesku přechází zrak.")


dialogId("tru-m-trpyt", "font_small", "Everything here gleams so. It makes me dizzy.")
dialogStr("Všechno se tu tak třpytí. Až z toho oči přecházejí.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/chest/dialogs_cs.lua <==

dialogId("tru-v-nasly", "font_big", "So we have finally found it.")
dialogStr("Tak jsme to konečně našly.")


dialogId("tru-m-co", "font_small", "What?")
dialogStr("Co?")


dialogId("tru-v-poklad", "font_big", "Captain Silver’s treasure, of course.")
dialogStr("No přeci poklady kapitána Silvera.")


dialogId("tru-v-gral", "font_big", "The Holy Grail, of course.")
dialogStr("No přeci svatý grál.")


dialogId("tru-v-vkupe", "font_big", "It’s neatly in one place: the treasure and the Grail.")
dialogStr("Tak to tu máme pěkně v kupě: poklady i Grál.")


dialogId("tru-m-zrada", "font_small", "I think it’s much too easy to be true.")
dialogStr("Jen aby v tom nebyla nějaká zrada.")


dialogId("tru-m-oznamit", "font_small", "I think that if it really was our goal, the game would let the player know.")
dialogStr("Já myslím, že kdyby to bylo skutečně ono, hra by to hráči nějak výrazně oznámila.")


dialogId("tru-v-stacit", "font_big", "But I have let them know. That could be enough.")
dialogStr("Však jsem mu to řekl. To by mu mohlo stačit.")


dialogId("tru-m-zpochybnit", "font_small", "But I have casted doubts on it. This could confuse them.")
dialogStr("Jenže já jsem to zpochybnila. To by jej mohlo zmást.")


dialogId("tru-v-nejspis", "font_big", "Well, all right. PROBABLY this is not what we are looking for.")
dialogStr("No tak dobře. Tak to NEJSPÍŠ ještě není ono.")


dialogId("tru-m-nejistota", "font_small", "That's better. There remains a bit of uncertainty.")
dialogStr("Tak je to lepší. Zůstává v tom střípek nejistoty.")


dialogId("tru-m-truhla0", "font_small", "Couldn’t we close that chest?")
dialogStr("Nemůže se ta truhla najednou zavřít?")


dialogId("tru-m-truhla1", "font_small", "What if we try to close that chest?")
dialogStr("Co kdybychom zkusili tu truhlu zavřít?")


dialogId("tru-v-truhla0", "font_big", "It would be much easier with the chest closed.")
dialogStr("Se zavřenou truhlou by bylo všechno jednodušší.")


dialogId("tru-v-truhla1", "font_big", "Try to push its lid.")
dialogStr("Zkus jí strčit do víka.")


dialogId("tru-m-vzit0", "font_small", "Won’t we take something with us?")
dialogStr("Nevezmeme si s sebou něco?")


dialogId("tru-m-vzit1", "font_small", "What about taking some treasure with us?")
dialogStr("Co si takhle vzít nějaký poklad s sebou?")


dialogId("tru-m-vzit2", "font_small", "Aren’t you sorry to leave all this treasure behind?")
dialogStr("Není ti líto, že tu necháme všechny ty poklady?")


dialogId("tru-v-vzit0", "font_big", "We will be glad if we manage to get out ourselves.")
dialogStr("Budeme rádi, když odjedem aspoň my samy.")


dialogId("tru-v-vzit1", "font_big", "Don’t forget our mission.")
dialogStr("Nezapomeň, že máme poslání.")


dialogId("tru-v-vzit2", "font_big", "The treasure would only hinder us.")
dialogStr("Poklady by nás jenom zdržovaly.")


dialogId("tru-v-zrak", "font_big", "All this glinting is a sight for the eyes.")
dialogStr("Už mě z toho lesku přechází zrak.")


dialogId("tru-m-trpyt", "font_small", "Everything here gleams so. It makes me dizzy.")
dialogStr("Všechno se tu tak třpytí. Až z toho oči přecházejí.")
